import { world, Player, Entity } from "@minecraft/server";

/**
 * Get the score of a target on an objective
 * @param {string} objective Objective to get a score from
 * @param {Entity|string} target The entity, player, or fake player to get the score of
 * @param {boolean} useZero Specifies whether to return NaN or 0 if an error is thrown
 * @returns {number} The target's score, or NaN / 0 if error
 * @example getScore('Money', player, true) //Returns the value of the scoreboard "Money", or 0 if error
 */
export function getScore(objective, target, useZero = false) {
    try {
        const oB = world.scoreboard.getObjective(objective)
        if (typeof target == 'string') return oB.getScore(oB.getParticipants().find(pT => pT.displayName == target))
        return oB.getScore(target.scoreboard)
    } catch {
        return useZero ? 0 : NaN
    }
}

function saveCordsToScoreboard(player) {
    player.runCommandAsync(`scoreboard players set @s[tag=accepted] lcaX ${Math.floor(player.location.x)}`)
    player.runCommandAsync(`scoreboard players set @s[tag=accepted] lcaY ${Math.floor(player.location.y)}`)
    player.runCommandAsync(`scoreboard players set @s[tag=accepted] lcaZ ${Math.floor(player.location.z)}`)
    player.runCommandAsync(`tellraw @s[tag=accepted] {"rawtext":[{"text":"[§eLCA§f] §7Your §aHome§7 is now set at your standing point: §6${Math.floor(player.location.x)} ${Math.floor(player.location.y)} ${Math.floor(player.location.z)}"}]}`)
    player.runCommandAsync(`tag @s[tag=accepted] add hashome`)
    player.runCommandAsync(`playsound random.toast @s[tag=accepted] ~~~ 1 3`)
    player.runCommandAsync(`tellraw @s[tag=!accepted,tag=!rejected] {"rawtext":[{"text":"[§eLCA§f] §cYou can't set home here! This is not your claim."}]}`)
    player.runCommandAsync(`tellraw @s[tag=rejected] {"rawtext":[{"text":"[§eLCA§f] §cYou can't set home in other dimensions except the overworld."}]}`)
    player.runCommandAsync(`playsound mob.creeper.say @s[tag=!accepted]`)
    player.runCommandAsync(`tag @s remove accepted`)
}
const entityId = "je:land"
world.events.entityHit.subscribe((data) => {
    if (data.hitEntity?.typeId === entityId && getScore("home", data.hitEntity) != 0 && data.entity instanceof Player && getScore("dimension", data.entity) === 1) {
        saveCordsToScoreboard(data.entity)
    }
})
world.events.entityHit.subscribe((data) => {
    if (data.hitEntity?.typeId === entityId && getScore("home", data.hitEntity) === 0 && data.entity instanceof Player && getScore("idtest", data.entity) === 0) {
        data.hitEntity.nameTag = data.entity.nameTag;
        data.hitEntity.runCommandAsync(`scoreboard players operation @s home = ${data.entity.nameTag} id`);
        data.hitEntity.runCommandAsync(`event entity @s je:white`);
        data.hitEntity.runCommandAsync(`particle minecraft:totem_particle ~~~`);
        data.entity.runCommandAsync(`playsound random.levelup @s ~~~ 1 2 1`);
    }
})

